;;; Directory Local Variables
;;; For more information see (info "(emacs) Directory Variables")

((nil
  (fill-column . 72)
  (sentence-end-double-space . t)
  (show-trailing-whitespace . t)
  (indent-tabs-mode . nil)))
